==================
icemac.addressbook
==================

Purpose:
    Store, search and export addresses and phone numbers using a web application.
Status:
    stable version, used in production; some features will be added in future

Copyright (c) 2008-2018 Michael Howitz

This package is licensed under the MIT License, see LICENSE.TXT inside the
package.

* Features_
* Screenshots_
* Download_
* Installation_
* Update_
* `Run the tests`_
* `Run the application`_
* `User management`_
* `To do`_

.. _Features : https://icemacaddressbook.readthedocs.io/en/latest/features.html
.. _Screenshots : https://icemacaddressbook.readthedocs.io/en/latest/screenshots.html
.. _Download : https://pypi.org/project/icemac.addressbook#files
.. _Installation : https://icemacaddressbook.readthedocs.io/en/latest/installation.html
.. _`User management` : https://icemacaddressbook.readthedocs.io/en/latest/usermanagement.html
.. _`Update` : https://icemacaddressbook.readthedocs.io/en/latest/update.html
.. _`Run the tests`: https://icemacaddressbook.readthedocs.io/en/latest/runthetests.html
.. _`Run the application` : https://icemacaddressbook.readthedocs.io/en/latest/runtheapplication.html
.. _`To do` : https://icemacaddressbook.readthedocs.io/en/latest/todo.html
